# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00g_test.ipynb.

# %% auto 0
__all__ = ['ROOT_DIR', 'SEG_IMAGE', 'SEG_MASK']

# %% ../nbs/00g_test.ipynb 2
import polvo as pv
from pathlib import Path

# %% ../nbs/00g_test.ipynb 3
ROOT_DIR =  Path(pv.__file__).parent.parent/'assets'
SEG_IMAGE = ROOT_DIR/'segmentation/image1.png'
SEG_MASK = ROOT_DIR/'segmentation/mask1.png'
