# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/polvo/',
                'doc_host': 'https://lgvaz.github.io',
                'git_url': 'https://github.com/lgvaz/polvo/',
                'lib_path': 'polvo'},
  'syms': { 'polvo.classification.baseline.baseline': { 'polvo.classification.baseline.baseline.FastaiMetricWrapper': ( 'classification.baseline.baseline.html#fastaimetricwrapper',
                                                                                                                        'polvo/classification/baseline/baseline.py'),
                                                        'polvo.classification.baseline.baseline.FastaiMetricWrapper.__init__': ( 'classification.baseline.baseline.html#fastaimetricwrapper.__init__',
                                                                                                                                 'polvo/classification/baseline/baseline.py'),
                                                        'polvo.classification.baseline.baseline.FastaiMetricWrapper.accumulate': ( 'classification.baseline.baseline.html#fastaimetricwrapper.accumulate',
                                                                                                                                   'polvo/classification/baseline/baseline.py'),
                                                        'polvo.classification.baseline.baseline.calculate_metrics': ( 'classification.baseline.baseline.html#calculate_metrics',
                                                                                                                      'polvo/classification/baseline/baseline.py'),
                                                        'polvo.classification.baseline.baseline.fixed_probs': ( 'classification.baseline.baseline.html#fixed_probs',
                                                                                                                'polvo/classification/baseline/baseline.py'),
                                                        'polvo.classification.baseline.baseline.random_probs': ( 'classification.baseline.baseline.html#random_probs',
                                                                                                                 'polvo/classification/baseline/baseline.py')},
            'polvo.classification.explorer': { 'polvo.classification.explorer.DataExplorer': ( 'classification.explorer.html#dataexplorer',
                                                                                               'polvo/classification/explorer.py'),
                                               'polvo.classification.explorer.DataExplorer.__init__': ( 'classification.explorer.html#dataexplorer.__init__',
                                                                                                        'polvo/classification/explorer.py'),
                                               'polvo.classification.explorer.DataExplorer._group_y': ( 'classification.explorer.html#dataexplorer._group_y',
                                                                                                        'polvo/classification/explorer.py'),
                                               'polvo.classification.explorer.DataExplorer.most_common': ( 'classification.explorer.html#dataexplorer.most_common',
                                                                                                           'polvo/classification/explorer.py'),
                                               'polvo.classification.explorer.DataExplorer.show_label': ( 'classification.explorer.html#dataexplorer.show_label',
                                                                                                          'polvo/classification/explorer.py'),
                                               'polvo.classification.explorer.DataExplorer.show_label_id': ( 'classification.explorer.html#dataexplorer.show_label_id',
                                                                                                             'polvo/classification/explorer.py'),
                                               'polvo.classification.explorer.DataExplorer.show_most_common': ( 'classification.explorer.html#dataexplorer.show_most_common',
                                                                                                                'polvo/classification/explorer.py')},
            'polvo.datasets.download': { 'polvo.datasets.download.snacks_tiny': ( 'datasets.download.html#snacks_tiny',
                                                                                  'polvo/datasets/download.py')},
            'polvo.segmentation.vis': { 'polvo.segmentation.vis.overlay_mask': ( 'segmentation.vis.html#overlay_mask',
                                                                                 'polvo/segmentation/vis.py')},
            'polvo.test': {},
            'polvo.utils.download': { 'polvo.utils.download.download': ('utils.download.html#download', 'polvo/utils/download.py'),
                                      'polvo.utils.download.download_and_extract': ( 'utils.download.html#download_and_extract',
                                                                                     'polvo/utils/download.py'),
                                      'polvo.utils.download.download_and_extract_gdrive': ( 'utils.download.html#download_and_extract_gdrive',
                                                                                            'polvo/utils/download.py'),
                                      'polvo.utils.download.download_gdrive': ( 'utils.download.html#download_gdrive',
                                                                                'polvo/utils/download.py')},
            'polvo.utils.io': { 'polvo.utils.io.RenderDict': ('utils.io.html#renderdict', 'polvo/utils/io.py'),
                                'polvo.utils.io.RenderDict.__init__': ('utils.io.html#renderdict.__init__', 'polvo/utils/io.py'),
                                'polvo.utils.io.RenderDict._ipython_display_': ( 'utils.io.html#renderdict._ipython_display_',
                                                                                 'polvo/utils/io.py'),
                                'polvo.utils.io._get_files': ('utils.io.html#_get_files', 'polvo/utils/io.py'),
                                'polvo.utils.io.extract_files': ('utils.io.html#extract_files', 'polvo/utils/io.py'),
                                'polvo.utils.io.get_files': ('utils.io.html#get_files', 'polvo/utils/io.py'),
                                'polvo.utils.io.get_image_files': ('utils.io.html#get_image_files', 'polvo/utils/io.py'),
                                'polvo.utils.io.mkdir': ('utils.io.html#mkdir', 'polvo/utils/io.py'),
                                'polvo.utils.io.open_image': ('utils.io.html#open_image', 'polvo/utils/io.py'),
                                'polvo.utils.io.open_json': ('utils.io.html#open_json', 'polvo/utils/io.py'),
                                'polvo.utils.io.open_mask': ('utils.io.html#open_mask', 'polvo/utils/io.py'),
                                'polvo.utils.io.open_txt': ('utils.io.html#open_txt', 'polvo/utils/io.py'),
                                'polvo.utils.io.save_image': ('utils.io.html#save_image', 'polvo/utils/io.py'),
                                'polvo.utils.io.save_json': ('utils.io.html#save_json', 'polvo/utils/io.py'),
                                'polvo.utils.io.save_txt': ('utils.io.html#save_txt', 'polvo/utils/io.py')},
            'polvo.utils.logging': {'polvo.utils.logging.pbar': ('utils.logging.html#pbar', 'polvo/utils/logging.py')},
            'polvo.utils.misc': { 'polvo.utils.misc.kwargs_grid': ('utils.misc.html#kwargs_grid', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.safe_zip': ('utils.misc.html#safe_zip', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.skip_error': ('utils.misc.html#skip_error', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.skip_error.__call__': ('utils.misc.html#skip_error.__call__', 'polvo/utils/misc.py'),
                                  'polvo.utils.misc.skip_error.__init__': ('utils.misc.html#skip_error.__init__', 'polvo/utils/misc.py')},
            'polvo.utils.script': { 'polvo.utils.script.call_parse': ('utils.script.html#call_parse', 'polvo/utils/script.py'),
                                    'polvo.utils.script.test_script': ('utils.script.html#test_script', 'polvo/utils/script.py')},
            'polvo.utils.visualization': { 'polvo.utils.visualization.get_image_grid': ( 'utils.visualization.html#get_image_grid',
                                                                                         'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.grid_from_sequence': ( 'utils.visualization.html#grid_from_sequence',
                                                                                             'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.image_grid': ( 'utils.visualization.html#image_grid',
                                                                                     'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.image_size': ( 'utils.visualization.html#image_size',
                                                                                     'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.image_sizes_hist': ( 'utils.visualization.html#image_sizes_hist',
                                                                                           'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.normalize_axes': ( 'utils.visualization.html#normalize_axes',
                                                                                         'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.plot_grid': ( 'utils.visualization.html#plot_grid',
                                                                                    'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.show_grid': ( 'utils.visualization.html#show_grid',
                                                                                    'polvo/utils/visualization.py'),
                                           'polvo.utils.visualization.show_image': ( 'utils.visualization.html#show_image',
                                                                                     'polvo/utils/visualization.py')}}}
